#'
utils::globalVariables(c("name", "iso_a2", "iso_a3", "geometry",
                         "MapFiller", "X", "Y",
                         "iso_a2_eh", "iso_a3_eh",
                         "map_df0"))
